pub struct SectionBuilder {
section: Section,
}Expand description
Fields
section: SectionImplementations
Sourceimpl SectionBuilder
impl SectionBuilder
pub(crate) fn new(id: impl Into<String>, title: impl Into<String>) -> Self
Sourcepub fn callout(self, level: CalloutLevel, text: impl Into<String>) -> Self
pub fn callout(self, level: CalloutLevel, text: impl Into<String>) -> Self
Add a highlighted callout box with a severity level.
Sourcepub fn heading(self, level: u8, text: impl Into<String>) -> Self
pub fn heading(self, level: u8, text: impl Into<String>) -> Self
Add a heading (level 1-6, maps to HTML heading levels).
Sourcepub fn kv(self, pairs: impl IntoIterator<Item = KvPair>) -> Self
pub fn kv(self, pairs: impl IntoIterator<Item = KvPair>) -> Self
Add a key-value list.
Sourcepub fn table(
self,
columns: impl IntoIterator<Item = Column>,
rows: impl IntoIterator<Item = Value>,
) -> Self
pub fn table( self, columns: impl IntoIterator<Item = Column>, rows: impl IntoIterator<Item = Value>, ) -> Self
Add a data table. Sortable by default, not searchable.
Sourcepub fn code(self, language: impl Into<String>, text: impl Into<String>) -> Self
pub fn code(self, language: impl Into<String>, text: impl Into<String>) -> Self
Add a syntax-highlighted code block.
Sourcepub fn json(self, data: impl Serialize) -> Self
pub fn json(self, data: impl Serialize) -> Self
Add an interactive JSON tree viewer (collapsed by default).
Sourcepub fn hex(self, bytes_b64: impl Into<String>, offset: u64) -> Self
pub fn hex(self, bytes_b64: impl Into<String>, offset: u64) -> Self
Add a hex dump. bytes_b64 is the data as base64, offset is the starting address.
Sourcepub fn image(self, artifact: impl Into<String>, caption: Option<String>) -> Self
pub fn image(self, artifact: impl Into<String>, caption: Option<String>) -> Self
Add an inline image resolved from a sibling artifact result.
Sourcepub fn download(
self,
artifact: impl Into<String>,
label: impl Into<String>,
) -> Self
pub fn download( self, artifact: impl Into<String>, label: impl Into<String>, ) -> Self
Add a download link resolved from a sibling artifact result.
Sourcepub fn iocs(self, items: impl IntoIterator<Item = Indicator>) -> Self
pub fn iocs(self, items: impl IntoIterator<Item = Indicator>) -> Self
Add a formatted IOC list.
Sourcepub fn ttps(self, items: impl IntoIterator<Item = Ttp>) -> Self
pub fn ttps(self, items: impl IntoIterator<Item = Ttp>) -> Self
Add a formatted MITRE ATT&CK technique list.
Sourcepub fn tree(self, nodes: impl IntoIterator<Item = TreeNode>) -> Self
pub fn tree(self, nodes: impl IntoIterator<Item = TreeNode>) -> Self
Add a collapsible tree (e.g. process tree, file hierarchy).
Sourcepub fn timeline(self, events: impl IntoIterator<Item = TimelineEvent>) -> Self
pub fn timeline(self, events: impl IntoIterator<Item = TimelineEvent>) -> Self
Add a chronological event timeline.
Sourcepub fn graph(
self,
nodes: impl IntoIterator<Item = GraphNode>,
edges: impl IntoIterator<Item = GraphEdge>,
) -> Self
pub fn graph( self, nodes: impl IntoIterator<Item = GraphNode>, edges: impl IntoIterator<Item = GraphEdge>, ) -> Self
Add a node-and-edge graph (e.g. network map, call graph).
pub(crate) fn build(self) -> Section